<?php

if ( ! defined( 'ABSPATH' ) ) exit;

add_action( 'template_redirect', 'gvnclg_process_autogenerate_link' );
function gvnclg_process_autogenerate_link() {


    if (!isset($_GET['uid']) || (isset($_SERVER['REQUEST_URI']) and strpos(sanitize_text_field(wp_unslash($_SERVER['REQUEST_URI'])), 'cartlink_autogenerate') === false) ) {
        return;
    }

    $unique_id = sanitize_text_field(wp_unslash($_GET['uid']));
    $data = gvnclg_get_pseudo_transient('cartlink_' . $unique_id);

    // Check for expiry
    if ($data && isset($data['expiry']) && time() > $data['expiry']) {
        die(esc_html__('expired cart', 'cartlink-generator' ));
    }


    if ($data && isset($data['products'])) {
        $products = $data['products'];
        $fixed_subtotal = isset($data['fixed_subtotal']) ? floatval($data['fixed_subtotal']) : null;

        if (!WC()->cart) {
            wc_load_cart();
        }

        WC()->cart->empty_cart();

        if ($fixed_subtotal !== null && $fixed_subtotal > 0) {
            WC()->session->set('fixed_subtotal', $fixed_subtotal);
        }

        WC()->session->set('generated_by_cartlink', true);

        foreach ($products as $product) {
            WC()->cart->add_to_cart(
                $product['id'], 
                $product['quantity'], 
                0, 
                [], 
                ['gvnclg_custom_price' => $product['price']]
            );
        }

        $where_to_redirect = defined('CARTGENERATOR_REDIRECT_TO_CART_INSTEAD_OF_CHECKOUT') ? wc_get_cart_url() : wc_get_checkout_url();
        wp_redirect($where_to_redirect);
        exit;
    }

    die(esc_html__('Some error occurred', 'cartlink-generator'));
}



add_action('woocommerce_cart_calculate_fees', 'gvnclg_apply_fixed_subtotal_adjustment', 20);
function gvnclg_apply_fixed_subtotal_adjustment($cart) {
    if (is_admin() && !defined('DOING_AJAX')) return;


    $fixed_subtotal = WC()->session->get( 'fixed_subtotal' );
    
    // Check if fee already exists to prevent multiple additions
    $fees = $cart->get_fees();
    foreach ($fees as $fee) {
        if ($fee->id === 'fixed-adjustment') {
            return; // Fee already exists, don't add again
        }
    }
    if ( $fixed_subtotal > 0 ) {
        $cart->add_fee(__('Fixed Adjustment', 'cartlink-generator'), -1*$fixed_subtotal, false);
    }
}



add_filter('woocommerce_coupon_is_valid', 'gvnclg_restrict_coupons_for_generated_carts', 10, 3);

function gvnclg_restrict_coupons_for_generated_carts($valid, $coupon, $cart) {

    if(defined('GUAVEN_CARTLINK_GENERATOR_ALLOW_COUPONS'))return $valid;

    if (WC()->session->get('generated_by_cartlink')) {
        throw new Exception(esc_html__('Coupons cannot be applied to this cart because it was generated using a special link.', 'cartlink-generator'));
    }

    return $valid;
}


// Hook to modify the cart item price
add_action( 'woocommerce_before_calculate_totals', 'gvnclg_set_custom_price_for_cart_items', 10, 1 );

function gvnclg_set_custom_price_for_cart_items( $cart ) {
    if ( is_admin() && ! defined( 'DOING_AJAX' ) ) {
        return;
    }

    // Loop through cart items to set custom price
    foreach ( $cart->get_cart() as $cart_item_key => $cart_item ) {
        if ( isset( $cart_item['gvnclg_custom_price'] ) ) {
            $cart_item['data']->set_price( $cart_item['gvnclg_custom_price'] );
        }
    }
}


add_filter('woocommerce_update_cart_validation', 'gvnclg_prevent_quantity_change', 10, 4);

function gvnclg_prevent_quantity_change($passed, $cart_item_key, $values, $quantity) {
    // Check if the cart was generated by CartLink Generator
    if (defined('CARTGENERATOR_FORBID_QUANTITY_UPDATE') and WC()->session->get('generated_by_cartlink')) {
        // Display error message and prevent update
        wc_add_notice(__('You can\'t modify this cart.', 'cartlink-generator'), 'error');
        return false; // Prevent the update
    }
    return $passed; // Allow the update
}




add_action('woocommerce_cart_loaded_from_session', 'gvnclg_save_initial_cart_quantities');

function gvnclg_save_initial_cart_quantities() {
    if (WC()->session->get('generated_by_cartlink')) {
        $initial_quantities = [];

        foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
            $initial_quantities[$cart_item_key] = $cart_item['quantity'];
        }

        WC()->session->set('cartlink_initial_quantities', $initial_quantities);
    }
}

add_action('woocommerce_update_order_review_fragments', 'gvnclg_block_quantity_updates_checkout');

function gvnclg_block_quantity_updates_checkout($fragments) {
    if (WC()->session->get('generated_by_cartlink')) {
        $initial_quantities = WC()->session->get('cartlink_initial_quantities') ?: [];

        foreach (WC()->cart->get_cart() as $cart_item_key => $cart_item) {
            if (isset($initial_quantities[$cart_item_key]) && $cart_item['quantity'] != $initial_quantities[$cart_item_key]) {
                // Reset the quantity to the original value
                WC()->cart->set_quantity($cart_item_key, $initial_quantities[$cart_item_key], true);
                // Add an error notice
                wc_add_notice(__('You can\'t modify this cart.', 'cartlink-generator'), 'error');
            }
        }
    }

    return $fragments;
}


add_action('woocommerce_cart_emptied', 'gvnclg_clear_generated_by_cartlink_session');

function gvnclg_clear_generated_by_cartlink_session() {
    // Check if the session data exists
    if (WC()->session->get('generated_by_cartlink')) {
        // Clear the 'generated_by_cartlink' session data
        WC()->session->__unset('generated_by_cartlink');
    }
}
